@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 begin
   require 'typhoeus'
 rescue LoadError
@@ -53,8 +55,11 @@ if defined?(Typhoeus)
         def self.build_request_signature(req)
           uri = WebMock::Util::URI.heuristic_parse(req.url)
           uri.path = uri.normalized_path.gsub("[^:]//","/")
+
+          headers = req.options[:headers]
+
           if req.options[:userpwd]
-            uri.user, uri.password = req.options[:userpwd].split(':')
+            headers['Authorization'] = WebMock::Util::Headers.basic_auth_header(req.options[:userpwd])
           end
 
           body = req.options[:body]
@@ -66,8 +71,8 @@ if defined?(Typhoeus)
           request_signature = WebMock::RequestSignature.new(
             req.options[:method] || :get,
             uri.to_s,
-            :body => body,
-            :headers => req.options[:headers]
+            body: body,
+            headers: headers
           )
 
           req.instance_variable_set(:@__webmock_request_signature, request_signature)
@@ -75,6 +80,7 @@ if defined?(Typhoeus)
           request_signature
         end
 
+
         def self.build_webmock_response(typhoeus_response)
           webmock_response = WebMock::Response.new
           webmock_response.status = [typhoeus_response.code, typhoeus_response.status_message]
@@ -86,19 +92,33 @@ if defined?(Typhoeus)
         def self.generate_typhoeus_response(request_signature, webmock_response)
           response = if webmock_response.should_timeout
             ::Typhoeus::Response.new(
-              :code         => 0,
-              :status_message => "",
-              :body         => "",
-              :headers => {},
-              :return_code => :operation_timedout
+              code: 0,
+              status_message: "",
+              body: "",
+              headers: {},
+              return_code: :operation_timedout,
+              total_time: 0.0,
+              starttransfer_time: 0.0,
+              appconnect_time: 0.0,
+              pretransfer_time: 0.0,
+              connect_time: 0.0,
+              namelookup_time: 0.0,
+              redirect_time: 0.0
             )
           else
             ::Typhoeus::Response.new(
-              :code         => webmock_response.status[0],
-              :status_message => webmock_response.status[1],
-              :body         => webmock_response.body,
-              :headers => webmock_response.headers,
-              :effective_url => request_signature.uri
+              code: webmock_response.status[0],
+              status_message: webmock_response.status[1],
+              body: webmock_response.body,
+              headers: webmock_response.headers,
+              effective_url: request_signature.uri,
+              total_time: 0.0,
+              starttransfer_time: 0.0,
+              appconnect_time: 0.0,
+              pretransfer_time: 0.0,
+              connect_time: 0.0,
+              namelookup_time: 0.0,
+              redirect_time: 0.0
             )
           end
           response.mock = :webmock
@@ -122,13 +142,13 @@ if defined?(Typhoeus)
               build_webmock_response(response)
           if response.mock
             WebMock::CallbackRegistry.invoke_callbacks(
-              {:lib => :typhoeus},
+              {lib: :typhoeus},
               request_signature,
               webmock_response
             )
           else
             WebMock::CallbackRegistry.invoke_callbacks(
-              {:lib => :typhoeus, :real_request => true},
+              {lib: :typhoeus, real_request: true},
               request_signature,
               webmock_response
             )
@@ -152,7 +172,7 @@ if defined?(Typhoeus)
                 request.execute_headers_callbacks(response)
               end
               if request.respond_to?(:streaming?) && request.streaming?
-                response.options[:response_body] = ""
+                response.options[:response_body] = "".dup
                 request.on_body.each { |callback| callback.call(webmock_response.body, response) }
               end
               request.finish(response)
