@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'webmock'
 
 # RSpec 1.x and 2.x compatibility
@@ -33,7 +35,8 @@ RSPEC_CONFIGURER.configure { |config|
     WebMock.disable!
   end
 
-  config.after(:each) do
+  config.around(:each) do |example|
+    example.run
     WebMock.reset!
   end
 }
