@@ -50,13 +50,16 @@ module EMHttpRequestSpecHelper
   end
 
   def client_timeout_exception_class
-    'Errno::ETIMEDOUT'
+    RuntimeError # 'Errno::ETIMEDOUT'
   end
 
   def connection_refused_exception_class
     RuntimeError
   end
 
+  def connection_error_class
+  end
+
   def http_library
     :em_http_request
   end
