@@ -8,7 +8,10 @@ module HttpRbSpecHelper
       chain = chain.basic_auth(user: basic_auth[0], pass: basic_auth[1])
     end
 
-    response = chain.request(method, normalize_uri(uri), options)
+    ssl_ctx = OpenSSL::SSL::SSLContext.new
+    ssl_ctx.verify_mode = OpenSSL::SSL::VERIFY_NONE
+
+    response = chain.request(method, normalize_uri(uri), options.merge(ssl_context: ssl_ctx))
 
     OpenStruct.new({
       body: response.body.to_s,
@@ -20,7 +23,7 @@ module HttpRbSpecHelper
 
   def client_timeout_exception_class
     return Errno::ETIMEDOUT if HTTP::VERSION < "1.0.0"
-    HTTP::ConnectionError
+    HTTP::TimeoutError
   end
 
   def connection_refused_exception_class
@@ -28,6 +31,9 @@ module HttpRbSpecHelper
     HTTP::ConnectionError
   end
 
+  def connection_error_class
+  end
+
   def http_library
     :http_rb
   end
