@@ -6,7 +6,7 @@ require 'stringio'
 require 'acceptance/net_http/net_http_shared'
 require 'support/webmock_server'
 
-describe "Real Net:HTTP without webmock", :without_webmock => true do
+describe "Real Net:HTTP without webmock", without_webmock: true do
   before(:all) do
     raise "WebMock has no access here!!!" if defined?(WebMock::NetHTTPUtility)
     WebMockServer.instance.start
@@ -17,4 +17,4 @@ describe "Real Net:HTTP without webmock", :without_webmock => true do
   end
 
   it_should_behave_like "Net::HTTP"
-end
\ No newline at end of file
+end
