@@ -69,6 +69,44 @@ describe WebMock::RequestStub do
       expect(@request_stub.response.status).to eq([500, ""])
     end
 
+    it "should json-ify an Array body" do
+      @request_stub.to_return_json(body: [{abc: "def" }])
+      expect(@request_stub.response.body).to eq('[{"abc":"def"}]')
+    end
+
+    it "should json-ify any object responding to `to_json`" do
+      record = double("SomeRecord")
+      allow(record).to receive_messages(to_json: '{"what":"something"}.')
+
+      @request_stub.to_return_json(body: record)
+      expect(@request_stub.response.body).to eq('{"what":"something"}.')
+    end
+
+    it "should not over-json-ify a String body" do
+      @request_stub.to_return_json(body: '{"abc":"def"}')
+      expect(@request_stub.response.body).to eq('{"abc":"def"}')
+    end
+
+    it "should evaluate a callable proc or lambda body at the time of response being returned and not at the time of stub declaration" do
+      record = double("SomeRecord")
+      allow(record).to receive_messages(to_json: '{"what":"something callable"}.')
+
+      @request_stub.to_return_json(body: (->(request) { record }))
+
+      allow(record).to receive_messages(to_json: '{"what":"something else callable"}.')
+      expect(@request_stub.response.body.call(double(WebMock::RequestSignature))).to eq('{"what":"something else callable"}.')
+    end
+
+    it "should evaluate a callable proc or lambda body, even if it takes no args" do
+      record = double("SomeRecord")
+      allow(record).to receive_messages(to_json: '{"what":"something callable"}.')
+
+      @request_stub.to_return_json(body: -> { record })
+
+      allow(record).to receive_messages(to_json: '{"what":"something else callable"}.')
+      expect(@request_stub.response.body.call(double(WebMock::RequestSignature))).to eq('{"what":"something else callable"}.')
+    end
+
     it "should apply the content_type header" do
       @request_stub.to_return_json(body: {abc: "def"}, status: 500)
       expect(@request_stub.response.headers).to eq({"Content-Type"=>"application/json"})
