@@ -78,10 +78,28 @@ module SharedTest
 
   def test_verification_that_expected_request_occured_with_excluding_query_params
     stub_request(:any, 'http://www.example.com').with(query: hash_excluding('a' => ['b', 'c']))
-    http_request(:get, 'http://www.example.com/?a[]=x&a[]=y&x=1')
+    http_request(:get, 'http://www.example.com/?a[]=b&a[]=y&x=1')
     assert_requested(:get, 'http://www.example.com', query: hash_excluding('a' => ['b', 'c']))
   end
 
+  def test_verification_that_expected_request_occured_with_hash_excluding_body
+    stub_request(:post, 'http://www.example.com').with(body: hash_excluding('a' => ['b', 'c']))
+    http_request(:post, 'http://www.example.com/',
+      body: 'a[]=b&a[]=y&x=1',
+      headers: {'Content-Type' => 'application/x-www-form-urlencoded'}
+    )
+    assert_requested(:post, 'http://www.example.com', body: hash_excluding('a' => ['b', 'c']))
+  end
+
+  def test_verification_that_expected_request_not_occured_with_hash_excluding_body
+    stub_request(:post, 'http://www.example.com').with(body: hash_excluding('a' => ['b', 'c']))
+    http_request(:post, 'http://www.example.com/',
+      body: 'a[]=b&a[]=c&x=1',
+      headers: {'Content-Type' => 'application/x-www-form-urlencoded'}
+    )
+    assert_not_requested(:post, 'http://www.example.com', body: hash_excluding('a' => ['b', 'c']))
+  end
+
   def test_verification_that_non_expected_request_didnt_occur
     expected_message = %r(The request GET http://www.example.com/ was not expected to execute but it executed 1 time\n\nThe following requests were made:\n\nGET http://www.example.com/ with headers .+ was made 1 time\n\n============================================================)
     assert_fail(expected_message) do
